@@ -241,7 +241,7 @@ QList<QAction *> KRichTextWidget::createActions()
         d->action_text_background_color = new QAction(QIcon::fromTheme(QStringLiteral("format-fill-color")),
                 i18nc("@action", "Text &Highlight..."), this);
         d->richTextActionList.append((d->action_text_background_color));
-        d->action_text_foreground_color->setObjectName(QStringLiteral("format_text_background_color"));
+        d->action_text_background_color->setObjectName(QStringLiteral("format_text_background_color"));
         connect(d->action_text_background_color, SIGNAL(triggered()), this, SLOT(_k_setTextBackgroundColor()));
     } else {
         d->action_text_background_color = 0;
@@ -251,7 +251,7 @@ QList<QAction *> KRichTextWidget::createActions()
         //Font Family
         d->action_font_family = new KFontAction(i18nc("@action", "&Font"), this);
         d->richTextActionList.append((d->action_font_family));
-        d->action_text_foreground_color->setObjectName(QStringLiteral("format_font_family"));
+        d->action_font_family->setObjectName(QStringLiteral("format_font_family"));
         connect(d->action_font_family, SIGNAL(triggered(QString)), this, SLOT(setFontFamily(QString)));
     } else {
         d->action_font_family = 0;
@@ -261,7 +261,7 @@ QList<QAction *> KRichTextWidget::createActions()
         //Font Size
         d->action_font_size = new KFontSizeAction(i18nc("@action", "Font &Size"), this);
         d->richTextActionList.append((d->action_font_size));
-        d->action_text_foreground_color->setObjectName(QStringLiteral("format_font_size"));
+        d->action_font_size->setObjectName(QStringLiteral("format_font_size"));
         connect(d->action_font_size, SIGNAL(fontSizeChanged(int)), this, SLOT(setFontSize(int)));
     } else {
         d->action_font_size = 0;
@@ -274,7 +274,7 @@ QList<QAction *> KRichTextWidget::createActions()
         bold.setBold(true);
         d->action_text_bold->setFont(bold);
         d->richTextActionList.append((d->action_text_bold));
-        d->action_text_foreground_color->setObjectName(QStringLiteral("format_text_bold"));
+        d->action_text_bold->setObjectName(QStringLiteral("format_text_bold"));
         d->action_text_bold->setShortcut(Qt::CTRL + Qt::Key_B);
         connect(d->action_text_bold, SIGNAL(triggered(bool)), this, SLOT(setTextBold(bool)));
     } else {
@@ -288,7 +288,7 @@ QList<QAction *> KRichTextWidget::createActions()
         italic.setItalic(true);
         d->action_text_italic->setFont(italic);
         d->richTextActionList.append((d->action_text_italic));
-        d->action_text_foreground_color->setObjectName(QStringLiteral("format_text_italic"));
+        d->action_text_italic->setObjectName(QStringLiteral("format_text_italic"));
         d->action_text_italic->setShortcut(Qt::CTRL + Qt::Key_I);
         connect(d->action_text_italic, SIGNAL(triggered(bool)),
                 this, SLOT(setTextItalic(bool)));
@@ -303,7 +303,7 @@ QList<QAction *> KRichTextWidget::createActions()
         underline.setUnderline(true);
         d->action_text_underline->setFont(underline);
         d->richTextActionList.append((d->action_text_underline));
-        d->action_text_foreground_color->setObjectName(QStringLiteral("format_text_underline"));
+        d->action_text_underline->setObjectName(QStringLiteral("format_text_underline"));
         d->action_text_underline->setShortcut(Qt::CTRL + Qt::Key_U);
         connect(d->action_text_underline, SIGNAL(triggered(bool)),
                 this, SLOT(setTextUnderline(bool)));
@@ -314,8 +314,11 @@ QList<QAction *> KRichTextWidget::createActions()
     if (d->richTextSupport & SupportStrikeOut) {
         d->action_text_strikeout = new KToggleAction(QIcon::fromTheme(QStringLiteral("format-text-strikethrough")),
                 i18nc("@action", "&Strike Out"), this);
+        QFont strikeout;
+        strikeout.setStrikeOut(true);
+        d->action_text_strikeout->setFont(strikeout);
         d->richTextActionList.append((d->action_text_strikeout));
-        d->action_text_foreground_color->setObjectName(QStringLiteral("format_text_strikethrough"));
+        d->action_text_strikeout->setObjectName(QStringLiteral("format_text_strikeout"));
         d->action_text_strikeout->setShortcut(Qt::CTRL + Qt::Key_L);
         connect(d->action_text_strikeout, SIGNAL(triggered(bool)),
                 this, SLOT(setTextStrikeOut(bool)));
@@ -329,7 +332,7 @@ QList<QAction *> KRichTextWidget::createActions()
                 i18nc("@action", "Align &Left"), this);
         d->action_align_left->setIconText(i18nc("@label left justify", "Left"));
         d->richTextActionList.append((d->action_align_left));
-        d->action_text_foreground_color->setObjectName(QStringLiteral("format_align_left"));
+        d->action_align_left->setObjectName(QStringLiteral("format_align_left"));
         connect(d->action_align_left, SIGNAL(triggered()),
                 this, SLOT(alignLeft()));
 
@@ -337,7 +340,7 @@ QList<QAction *> KRichTextWidget::createActions()
                 i18nc("@action", "Align &Center"), this);
         d->action_align_center->setIconText(i18nc("@label center justify", "Center"));
         d->richTextActionList.append((d->action_align_center));
-        d->action_text_foreground_color->setObjectName(QStringLiteral("format_align_center"));
+        d->action_align_center->setObjectName(QStringLiteral("format_align_center"));
         connect(d->action_align_center, SIGNAL(triggered()),
                 this, SLOT(alignCenter()));
 
@@ -345,7 +348,7 @@ QList<QAction *> KRichTextWidget::createActions()
                 i18nc("@action", "Align &Right"), this);
         d->action_align_right->setIconText(i18nc("@label right justify", "Right"));
         d->richTextActionList.append((d->action_align_right));
-        d->action_text_foreground_color->setObjectName(QStringLiteral("format_align_right"));
+        d->action_align_right->setObjectName(QStringLiteral("format_align_right"));
         connect(d->action_align_right, SIGNAL(triggered()),
                 this, SLOT(alignRight()));
 
@@ -353,7 +356,7 @@ QList<QAction *> KRichTextWidget::createActions()
                 i18nc("@action", "&Justify"), this);
         d->action_align_justify->setIconText(i18nc("@label justify fill", "Justify"));
         d->richTextActionList.append((d->action_align_justify));
-        d->action_text_foreground_color->setObjectName(QStringLiteral("format_align_justify"));
+        d->action_align_justify->setObjectName(QStringLiteral("format_align_justify"));
         connect(d->action_align_justify, SIGNAL(triggered()),
                 this, SLOT(alignJustify()));
 
@@ -374,7 +377,7 @@ QList<QAction *> KRichTextWidget::createActions()
                 i18nc("@action", "Left-to-Right"), this);
         d->action_direction_ltr->setIconText(i18nc("@label left-to-right", "Left-to-Right"));
         d->richTextActionList.append(d->action_direction_ltr);
-        d->action_text_foreground_color->setObjectName(QStringLiteral("direction_ltr"));
+        d->action_direction_ltr->setObjectName(QStringLiteral("direction_ltr"));
         connect(d->action_direction_ltr, SIGNAL(triggered()),
                 this, SLOT(makeLeftToRight()));
 
@@ -382,7 +385,7 @@ QList<QAction *> KRichTextWidget::createActions()
                 i18nc("@action", "Right-to-Left"), this);
         d->action_direction_rtl->setIconText(i18nc("@label right-to-left", "Right-to-Left"));
         d->richTextActionList.append(d->action_direction_rtl);
-        d->action_text_foreground_color->setObjectName(QStringLiteral("direction_rtl"));
+        d->action_direction_rtl->setObjectName(QStringLiteral("direction_rtl"));
         connect(d->action_direction_rtl, SIGNAL(triggered()),
                 this, SLOT(makeRightToLeft()));
 
@@ -411,7 +414,7 @@ QList<QAction *> KRichTextWidget::createActions()
         d->action_list_style->setItems(listStyles);
         d->action_list_style->setCurrentItem(0);
         d->richTextActionList.append((d->action_list_style));
-        d->action_text_foreground_color->setObjectName(QStringLiteral("format_list_style"));
+        d->action_list_style->setObjectName(QStringLiteral("format_list_style"));
         connect(d->action_list_style, SIGNAL(triggered(int)),
                 this, SLOT(_k_setListStyle(int)));
         connect(d->action_list_style, SIGNAL(triggered()),
@@ -424,7 +427,7 @@ QList<QAction *> KRichTextWidget::createActions()
         d->action_list_indent = new QAction(QIcon::fromTheme(QStringLiteral("format-indent-more")),
                                             i18nc("@action", "Increase Indent"), this);
         d->richTextActionList.append((d->action_list_indent));
-        d->action_text_foreground_color->setObjectName(QStringLiteral("format_list_indent_more"));
+        d->action_list_indent->setObjectName(QStringLiteral("format_list_indent_more"));
         connect(d->action_list_indent, SIGNAL(triggered()),
                 this, SLOT(indentListMore()));
         connect(d->action_list_indent, SIGNAL(triggered()),
@@ -437,7 +440,7 @@ QList<QAction *> KRichTextWidget::createActions()
         d->action_list_dedent = new QAction(QIcon::fromTheme(QStringLiteral("format-indent-less")),
                                             i18nc("@action", "Decrease Indent"), this);
         d->richTextActionList.append((d->action_list_dedent));
-        d->action_text_foreground_color->setObjectName(QStringLiteral("format_list_indent_less"));
+        d->action_list_dedent->setObjectName(QStringLiteral("format_list_indent_less"));
         connect(d->action_list_dedent, SIGNAL(triggered()),
                 this, SLOT(indentListLess()));
         connect(d->action_list_dedent, SIGNAL(triggered()),
@@ -450,7 +453,7 @@ QList<QAction *> KRichTextWidget::createActions()
         d->action_insert_horizontal_rule = new QAction(QIcon::fromTheme(QStringLiteral("insert-horizontal-rule")),
                 i18nc("@action", "Insert Rule Line"), this);
         d->richTextActionList.append((d->action_insert_horizontal_rule));
-        d->action_text_foreground_color->setObjectName(QStringLiteral("insert_horizontal_rule"));
+        d->action_insert_horizontal_rule->setObjectName(QStringLiteral("insert_horizontal_rule"));
         connect(d->action_insert_horizontal_rule, SIGNAL(triggered()),
                 this, SLOT(insertHorizontalRule()));
     } else {
@@ -461,7 +464,7 @@ QList<QAction *> KRichTextWidget::createActions()
         d->action_manage_link = new QAction(QIcon::fromTheme(QStringLiteral("insert-link")),
                                             i18nc("@action", "Link"), this);
         d->richTextActionList.append((d->action_manage_link));
-        d->action_text_foreground_color->setObjectName(QStringLiteral("manage_link"));
+        d->action_manage_link->setObjectName(QStringLiteral("manage_link"));
         connect(d->action_manage_link, SIGNAL(triggered()),
                 this, SLOT(_k_manageLink()));
     } else {
@@ -472,7 +475,7 @@ QList<QAction *> KRichTextWidget::createActions()
         d->action_format_painter = new KToggleAction(QIcon::fromTheme(QStringLiteral("draw-brush")),
                 i18nc("@action", "Format Painter"), this);
         d->richTextActionList.append((d->action_format_painter));
-        d->action_text_foreground_color->setObjectName(QStringLiteral("format_painter"));
+        d->action_format_painter->setObjectName(QStringLiteral("format_painter"));
         connect(d->action_format_painter, SIGNAL(toggled(bool)),
                 this, SLOT(_k_formatPainter(bool)));
     } else {
@@ -482,7 +485,7 @@ QList<QAction *> KRichTextWidget::createActions()
     if (d->richTextSupport & SupportToPlainText) {
         d->action_to_plain_text = new KToggleAction(i18nc("@action", "To Plain Text"), this);
         d->richTextActionList.append((d->action_to_plain_text));
-        d->action_text_foreground_color->setObjectName(QStringLiteral("action_to_plain_text"));
+        d->action_to_plain_text->setObjectName(QStringLiteral("action_to_plain_text"));
         connect(d->action_to_plain_text, SIGNAL(triggered()),
                 this, SLOT(switchToPlainText()));
     } else {
@@ -493,14 +496,14 @@ QList<QAction *> KRichTextWidget::createActions()
         d->action_text_subscript = new KToggleAction(QIcon::fromTheme(QStringLiteral("format-text-subscript")),
                 i18nc("@action", "Subscript"), this);
         d->richTextActionList.append((d->action_text_subscript));
-        d->action_text_foreground_color->setObjectName(QStringLiteral("format_text_subscript"));
+        d->action_text_subscript->setObjectName(QStringLiteral("format_text_subscript"));
         connect(d->action_text_subscript, SIGNAL(triggered(bool)),
                 this, SLOT(setTextSubScript(bool)));
 
         d->action_text_superscript = new KToggleAction(QIcon::fromTheme(QStringLiteral("format-text-superscript")),
                 i18nc("@action", "Superscript"), this);
         d->richTextActionList.append((d->action_text_superscript));
-        d->action_text_foreground_color->setObjectName(QStringLiteral("format_text_superscript"));
+        d->action_text_superscript->setObjectName(QStringLiteral("format_text_superscript"));
         connect(d->action_text_superscript, SIGNAL(triggered(bool)),
                 this, SLOT(setTextSuperScript(bool)));
     } else {
